@@ -83,7 +83,7 @@ void FileItemLinkingPlugin::Private::actionTriggered()
     bool link = action->property("link").toBool();
     QString activity = action->property("activity").toString();
 
-    KAMD_DBUS_DECL_INTERFACE(service, Resources/Linking, ResourcesLinking);
+    KAMD_DBUS_DECL_INTERFACE(service, "Resources/Linking", "ResourcesLinking");
 
     const auto urlList = items.urlList();
     for (const auto &item : urlList) {
@@ -100,7 +100,7 @@ QAction *FileItemLinkingPlugin::Private::basicAction(QWidget *parentWidget)
     root = new QAction(QIcon::fromTheme("activities"),
                                 i18n("Activities"), parentWidget);
 
-    rootMenu = new QMenu();
+    rootMenu = new QMenu(parentWidget);
     rootMenu->addAction(new QAction(i18n("Loading..."), this));
 
     connect(root, &QAction::hovered,
