@@ -164,14 +164,16 @@ private: // Private variables
     public:
         /**
          * Creates a new GetRequest object.
+         * Requests do not take ownership of the SFTP pointers! The caller is
+         * responsible for freeing them.
          * @param file the sftp_file object which should be transferred.
-         * @param sb the attributes of that sftp_file object.
+         * @param size the total size of the file.
          * @param maxPendingRequests the maximum number of parallel requests to start with.
          *                           The more are pending the higher the potential memory
          *                           foot print, however if the connection allows it
          *                           we'll get better throughput.
          */
-        GetRequest(sftp_file file, sftp_attributes sb, ushort maxPendingRequests = 128);
+        GetRequest(sftp_file file, uint64_t size, ushort maxPendingRequests = 128);
         /**
          * Removes all pending requests and closes the SFTP channel and attributes
          * in order to avoid memory leaks.
@@ -200,10 +202,10 @@ private: // Private variables
             uint64_t startOffset;
         };
 
-        sftp_file mFile;
-        sftp_attributes mSb;
-        ushort mMaxPendingRequests;
-        QQueue<Request> pendingRequests;
+        sftp_file m_file;
+        const uint64_t m_size; // size of file (max readable)
+        ushort m_maxPendingRequests;
+        QQueue<Request> m_pendingRequests;
     };
 
 private: // private methods
