@@ -21,11 +21,9 @@
 
 #include <kzip.h>
 
-// Qt
-#include <QPainter>
+#include <memory>
 #include <QImage>
 #include <QIODevice>
-#include <QFile>
 
 extern "C"
 {
@@ -53,51 +51,35 @@ bool KritaCreator::create(const QString &path, int width, int height, QImage &im
         return false;
     }
 
-    QImage thumbnail;
-    bool biggerSizeNeeded = true;
-
     // first check if normal thumbnail is good enough
     // ORA thumbnail?
-    const KArchiveEntry *entry = zip.directory()->entry(QLatin1String("Thumbnails/thumbnail.png"));
-    // KRA thumbnail
-    if (!entry || !entry->isFile()) {
-        entry = zip.directory()->entry(QLatin1String("preview.png"));
+    const KArchiveFile *entry = zip.directory()->file(QLatin1String("Thumbnails/thumbnail.png"));
+    if (!entry) {
+        // KRA thumbnail
+        entry = zip.directory()->file(QLatin1String("preview.png"));
     }
 
-    if (!entry || !entry->isFile()) {
+    if (!entry) {
         return false;
     }
 
-    const KZipFileEntry* fileZipEntry = static_cast<const KZipFileEntry*>(entry);
-    bool thumbLoaded = thumbnail.loadFromData(fileZipEntry->data(), "PNG");
-    if (thumbLoaded) {
-        biggerSizeNeeded = (thumbnail.width() < width || thumbnail.height() < height);
-    }
-
-    if (biggerSizeNeeded || !thumbLoaded) {
-        entry = zip.directory()->entry(QLatin1String("mergedimage.png"));
-    }
-
-    if (entry && entry->isFile()) {
-        fileZipEntry = static_cast<const KZipFileEntry*>(entry);
-        thumbLoaded = thumbnail.loadFromData(fileZipEntry->data(), "PNG");
-        if (thumbLoaded) {
-            thumbnail = thumbnail.scaled(width, height, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-        } else {
-            return false;
-        }
-    }
-
-    if (!thumbnail.isNull()) {
-        // transparent areas put a white background behind the thumbnail
-        // (or better checkerboard?)
-        image = QImage(thumbnail.size(), QImage::Format_RGB32);
-        image.fill(QColor(Qt::white).rgb());
-        QPainter p(&image);
-        p.drawImage(QPoint(0, 0), thumbnail);
-
+    std::unique_ptr<QIODevice> fileDevice{entry->createDevice()};
+    bool thumbLoaded = image.load(fileDevice.get(), "PNG");
+    // The requested size is a boundingbox, so meeting one size is sufficient
+    if (thumbLoaded && ((image.width() >= width) || (image.height() >= height))) {
         return true;
     }
 
+    entry = zip.directory()->file(QLatin1String("mergedimage.png"));
+    if (entry) {
+        QImage thumbnail;
+        fileDevice.reset(entry->createDevice());
+        thumbLoaded = thumbnail.load(fileDevice.get(), "PNG");
+        if (thumbLoaded) {
+            image = thumbnail;
+            return true;
+        }
+    }
+
     return false;
 }
